# API Reference

## TextualApp

```{eval-rst}
.. autoclass:: genro_textual.TextualApp
   :members:
   :undoc-members:
```

## TextualBuilder

```{eval-rst}
.. autoclass:: genro_textual.textual_builder.TextualBuilder
   :members:
   :undoc-members:
```

## TextualCompiler

```{eval-rst}
.. autoclass:: genro_textual.textual_compiler.TextualCompiler
   :members:
   :undoc-members:
```

## LiveApp

```{eval-rst}
.. autoclass:: genro_textual.textual_app.LiveApp
   :members:
   :undoc-members:
```
